onReplaceTap property
Optional callback triggered when the replace button is pressed for a specific file.
Implementation
final void Function(
int index,
TogeFileUploadSource source,
)? onReplaceTap;
Optional callback triggered when the replace button is pressed for a specific file.
final void Function(
int index,
TogeFileUploadSource source,
)? onReplaceTap;